<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="gl">
<context>
    <name>Fm::FontButton</name>
    <message>
        <location filename="../fontbutton.cpp" line="46"/>
        <source>Bold</source>
        <translation>Grosa</translation>
    </message>
    <message>
        <location filename="../fontbutton.cpp" line="50"/>
        <source>Italic</source>
        <translation>Itálica</translation>
    </message>
</context>
<context>
    <name>MainDialog</name>
    <message>
        <location filename="../obconf.ui" line="63"/>
        <source>Mouse</source>
        <translation>Rato</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="14"/>
        <source>Window Manager Preferences</source>
        <translation>Preferencias do xestor de xanelas</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="38"/>
        <source>Theme</source>
        <translation>Tema</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="43"/>
        <source>Appearance</source>
        <translation>Aparencia</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="48"/>
        <source>Font</source>
        <translation>Tipo de letra</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="53"/>
        <location filename="../obconf.ui" line="114"/>
        <source>Windows</source>
        <translation>Xanelas</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="58"/>
        <source>Move &amp; Resize</source>
        <translation>Mover e reaxustar</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="68"/>
        <source>Desktops</source>
        <translation>Escritorios</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="73"/>
        <source>Margins</source>
        <translation>Marxes</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="78"/>
        <source>Dock</source>
        <translation>Doca</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="137"/>
        <source>Window Titles</source>
        <translation>Títulos de xanela</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="143"/>
        <source>Button order:</source>
        <translation>Orde dos botóns:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="439"/>
        <source>Moving and Resizing Windows</source>
        <translation>Mover e redimensionar as xanelas</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="542"/>
        <source>Information Dialog</source>
        <translation>Diálogo de información</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="701"/>
        <source>Focusing Windows</source>
        <translation>Xanelas en foco</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="710"/>
        <source>Focus windows when the mouse pointer moves over them</source>
        <translation>Pon en foco as xanelas cando o rato pasa sobre elas</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="768"/>
        <source>Titlebar</source>
        <translation>Barra de título</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="905"/>
        <source>Desktop Margins</source>
        <translation>Marxes do escritorio</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="911"/>
        <source>Desktop margins are reserved areas on the edge of your screen.  New windows will not be placed within a margin, and maximized windows will not cover them.</source>
        <translation>As marxes de escritorio son áreas reservadas no bordo da pantalla.  As novas xanelas no se situaran dentro dunha marxe, e as xanelas maximizadas non os cubrirán.</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="921"/>
        <source>Left:</source>
        <translation>Esquerda:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="935"/>
        <location filename="../obconf.ui" line="956"/>
        <location filename="../obconf.ui" line="977"/>
        <location filename="../obconf.ui" line="998"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="942"/>
        <source>Top:</source>
        <translation>Arriba:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="963"/>
        <source>Right:</source>
        <translation>Dereita:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="984"/>
        <source>Bottom:</source>
        <translation>Abaixo:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="329"/>
        <source>All monitors</source>
        <translation>Todos os monitores</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="334"/>
        <source>The active monitor</source>
        <translation>O monitor activo</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="339"/>
        <source>The monitor with the mouse</source>
        <translation>O monitor co rato</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="354"/>
        <source>Primary Monitor</source>
        <translation>Monitor primario</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="360"/>
        <source>The primary monitor is where Openbox will place dialogs, such as the one used for cycling windows.</source>
        <translation>O monitor primario é no que o Openbox colocará os cadros de diálogo, como o que se utiliza para o carrusel de xanelas.</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="381"/>
        <source>Fixed Monitor</source>
        <translation>Monitor fixo</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="386"/>
        <source>Active Monitor</source>
        <translation>Monitor activo</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="391"/>
        <source>Monitor With Mouse Pointer</source>
        <translation>Monitor co punteiro do rato</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="549"/>
        <location filename="../obconf.ui" line="578"/>
        <source>Centered</source>
        <translation>Centrado</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="554"/>
        <source>From left edge</source>
        <translation>Dende o bordo esquerdo</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="559"/>
        <source>From right edge</source>
        <translation>Dende o bordo dereito</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="583"/>
        <source>From top edge</source>
        <translation>Dende o bordo superior</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="588"/>
        <source>From bottom edge</source>
        <translation>Dende o bordo inferior</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="641"/>
        <source>When resizing terminal windows</source>
        <translation>Ao cambiar o tamaño das xanelas do terminal</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="646"/>
        <source>Always</source>
        <translation>Sempre</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="651"/>
        <source>Never</source>
        <translation>Nunca</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="660"/>
        <source>Centered on the window</source>
        <translation>Centrado na xanela</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="665"/>
        <source>Above the window</source>
        <translation>Por riba da xanela</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="670"/>
        <source>Fixed position on screen</source>
        <translation>Posición fixa na pantalla</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="785"/>
        <source>Maximizes the window</source>
        <translation>Maximizar a xanela</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="790"/>
        <source>Shades the window</source>
        <translation>Ensombrecer a xanela</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="153"/>
        <source>N: Window icon
L: Window label (Title)
I: Iconify (Minimize)
M: Maximize
C: Close
S: Shade (Roll up)
D: Omnipresent (On all desktops)</source>
        <translation>N: Icona da xanela
L: Etiqueta da xanela (título)
I: Iconificar (minimizar)
M: Maximizar
C: Pechar
S: Cortina (enrolar)
D: Omnipresente (en todos os escritorios)</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="344"/>
        <source>Primary monitor</source>
        <translation>Monitor primario</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1025"/>
        <source>The dock is a special container for &quot;dockapps&quot;, or dock applications.  It is not visible on screen until a dockapp is run.  Dockapps can be used to show things like a clock, or to provide you with a system tray.</source>
        <translation>A doca é un contedor especial para «dockapps» (aplicacións ancorábeis) ou trebellos.  Non se ve na pantalla ata que se executa un trebello. Os trebellos poden empregarse para amosar cousas coma un reloxo, ou para fornecerlle unha área de notificación ao sistema.</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1041"/>
        <source>Position</source>
        <translation>Posición</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1053"/>
        <source>&amp;Position:</source>
        <translation>&amp;Posición:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1067"/>
        <source>Top Left</source>
        <translation>Arriba á esquerda</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1072"/>
        <source>Top</source>
        <translation>Arriba</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1077"/>
        <source>Top Right</source>
        <translation>Arriba á dereita</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1082"/>
        <source>Left</source>
        <translation>Esquerda</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1087"/>
        <source>Right</source>
        <translation>Dereita</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1092"/>
        <source>Bottom Left</source>
        <translation>Abaixo á esquerda</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1097"/>
        <source>Bottom</source>
        <translation>Abaixo</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1102"/>
        <source>Bottom Right</source>
        <translation>Abaixo á dereita</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1107"/>
        <source>Floating</source>
        <translation>Flotante</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1121"/>
        <source>&amp;Floating position:</source>
        <translation>Posición &amp;flotante:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1146"/>
        <source>x</source>
        <translation>x</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1162"/>
        <source>Allow &amp;windows to be placed within the dock&apos;s area</source>
        <translation>Permitir que as &amp;xanelas sexan colocadas na área da doca</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1169"/>
        <source>&amp;Orientation: </source>
        <translation>&amp;Orientación: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1183"/>
        <source>Vertical</source>
        <translation>Vertical</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1188"/>
        <source>Horizontal</source>
        <translation>Horizontal</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1199"/>
        <source>Stacking</source>
        <translation>Amoreado</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1205"/>
        <source>Keep dock &amp;above other windows</source>
        <translation>Manter a &amp;doca sobre as outras xanelas</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1212"/>
        <source>A&amp;llow dock to be both above and below windows</source>
        <translation>Per&amp;mitir que a doca estea tanto enriba coma embaixo das xanelas</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1219"/>
        <source>Keep dock &amp;below other windows</source>
        <translation>Manter a doca &amp;baixo as outras xanelas</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1229"/>
        <source>Hiding</source>
        <translation>Agochamento</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1235"/>
        <source>&amp;Delay before hiding:</source>
        <translation>&amp;Demora antes de agochar:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1245"/>
        <source>Delay before &amp;showing:</source>
        <translation>Demora antes de amo&amp;sar:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1275"/>
        <source>&amp;Hide off screen</source>
        <translation>Agac&amp;har a pantalla</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="1306"/>
        <source>About</source>
        <translation>Sobre</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="96"/>
        <source>&amp;Install a new theme...</source>
        <translation>&amp;Instalar un tema novo…</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="103"/>
        <source>Create a theme &amp;archive (.obt)...</source>
        <translation>Crear un &amp;arquivo de tema (.obt)...</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="120"/>
        <source>&amp;Windows retain a border when undecorated</source>
        <translation>As &amp;xanelas conservan un bordo cando non hai decoración</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="127"/>
        <source>A&amp;nimate iconify and restore</source>
        <translation>A&amp;nimar a iconificación e a restauración</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="231"/>
        <source>&amp;Active window title: </source>
        <translation>Título da xanela &amp;activa: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="241"/>
        <source>&amp;Inactive window title: </source>
        <translation>Título da xanela &amp;inactiva: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="251"/>
        <source>Menu &amp;header: </source>
        <translation>&amp;Cabeceira do menú: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="261"/>
        <source>&amp;Menu Item: </source>
        <translation>&amp;Elemento do menú: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="271"/>
        <source>Active &amp;On-screen display: </source>
        <translation>Vista en &amp;pantalla activada: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="281"/>
        <source>Inactive O&amp;n-screen display: </source>
        <translation>Vista en pa&amp;ntalla desactivada: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="295"/>
        <source>Focus &amp;new windows when they appear</source>
        <translation>Poñer en foco as xanelas &amp;novas cando aparezan</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="302"/>
        <source>&amp;Place new windows under the mouse pointer</source>
        <translation>&amp;Poñer as xanelas novas baixo o punteiro do rato</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="309"/>
        <source>&amp;Center new windows when they are placed</source>
        <translation>&amp;Centrar as novas xanelas ao seren posicionadas</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="318"/>
        <source>Prefer to place new windows &amp;on:</source>
        <translation>É preferíbel poñer as &amp;novas xanelas en:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="370"/>
        <source>Primary &amp;monitor:</source>
        <translation>Monitor &amp;primario:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="399"/>
        <source>&amp;Fixed monitor:</source>
        <translation>Monitor &amp;fixo:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="445"/>
        <source>Update the window contents while &amp;resizing</source>
        <translation>Actualizar o contido das xanelas ao &amp;redimensionar</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="452"/>
        <source>Drag &amp;threshold distance:</source>
        <translation>&amp;Limiar de distancia do arrastre:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="472"/>
        <source>Amount of resistance against other &amp;windows:</source>
        <translation>Canta resistencia fronte a outras &amp;xanelas:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="492"/>
        <source>Amount of resistance against screen &amp;edges:</source>
        <translation>Canta resistencia fronte aos &amp;bordos da pantalla:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="512"/>
        <source>&amp;Amount of time to wait before switching:</source>
        <translation>Cantidade de &amp;tempo que debe transcorrer antes de cambiar:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="532"/>
        <source>&amp;Switch desktops when moving a window past the screen edge</source>
        <translation>&amp;Cambiar entre escritorios cando se move unha xanela fora do bordo da pantalla</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="567"/>
        <source>Fixed &amp;y position:</source>
        <translation>Posición &amp;Y fixa:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="596"/>
        <source>Information dialog&apos;s &amp;position:</source>
        <translation>&amp;Posición dos diálogos de información:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="606"/>
        <source>Fixed &amp;x position:</source>
        <translation>Posición &amp;X fixa:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="616"/>
        <source>Show &amp;information dialog:</source>
        <translation>Amosar o diálogo de &amp;información:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="722"/>
        <source>&amp;Delay before focusing and raising windows:</source>
        <translation>&amp;Demora antes de enfocar e elevar as xanelas:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="742"/>
        <source>Move focus under the mouse when &amp;switching desktops</source>
        <translation>Mover o foco baixo o rato ao &amp;cambiar de escritorio</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="749"/>
        <source>Move focus &amp;under the mouse when the mouse is not moving</source>
        <translation>Mover o foco &amp;baixo o rato cando se move o rato</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="756"/>
        <source>&amp;Raise windows when the mouse pointer moves over them</source>
        <translation>&amp;Elevar as xanelas cando o rato pase sobre elas</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="774"/>
        <source>Double click on the &amp;titlebar:</source>
        <translation>Duplo clic na barra de &amp;título:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="798"/>
        <source>Double click ti&amp;me:</source>
        <translation>Te&amp;mpo de duplo clic:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="838"/>
        <source>&amp;Show a notification when switching desktops</source>
        <translation>&amp;Amosar un aviso ao cambiar de escritorio</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="845"/>
        <source>&amp;Amount of time to show the notification for:</source>
        <translation>Cantidade de &amp;tempo durante o que amosar o aviso para:</translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="868"/>
        <source>&amp;Number of desktops: </source>
        <translation>&amp;Número de escritorios: </translation>
    </message>
    <message>
        <location filename="../obconf.ui" line="891"/>
        <source>&amp;Desktop names:</source>
        <translation>Nomes dos &amp;escritorios:</translation>
    </message>
</context>
<context>
    <name>Obconf::MainDialog</name>
    <message>
        <location filename="../mouse.cpp" line="57"/>
        <source>Custom actions</source>
        <translation>Accións personalizadas</translation>
    </message>
    <message>
        <location filename="../desktops.cpp" line="65"/>
        <location filename="../desktops.cpp" line="87"/>
        <location filename="../desktops.cpp" line="99"/>
        <source>(Unnamed desktop)</source>
        <translation>(Escritorio sen nome)</translation>
    </message>
    <message>
        <location filename="../maindialog.cpp" line="76"/>
        <source>About ObConf-Qt</source>
        <translation>Sobre o ObConf-Qt</translation>
    </message>
    <message>
        <location filename="../maindialog.cpp" line="77"/>
        <source>A preferences manager for Openbox

Copyright (c) 2014-2015

Authors:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;

The program is based on ObConf developed by the following developers.
* Dana Jansens &lt;danakj@orodu.net&gt;
* Tim Riley &lt;tr@slackzone.org&gt;
* Javeed Shaikh &lt;syscrash2k@gmail.com&gt;</source>
        <translation>Un administrador de preferencias para Openbox

Copyright (c) 2014-2015

Autores:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;

Este programa está baseado no ObConf, desenvolvido por:
* Dana Jansens &lt;danakj@orodu.net&gt;
* Tim Riley &lt;tr@slackzone.org&gt;
* Javeed Shaikh &lt;syscrash2k@gmail.com&gt;</translation>
    </message>
    <message>
        <location filename="../theme.cpp" line="149"/>
        <source>Choose an Openbox theme</source>
        <translation>Escoller un tema do Openbox</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../archive.cpp" line="26"/>
        <source>&quot;%1&quot; was installed to %2</source>
        <translation>«%1» foi instalado en %2</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="53"/>
        <source>&quot;%1&quot; was successfully created</source>
        <translation>«%1» foi creado satisfactoriamente</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="89"/>
        <source>Unable to create the theme archive &quot;%1&quot;.
The following errors were reported:
%2</source>
        <translation>Non foi posíbel crear o arquivo do tema «%1».
Informouse dos seguintes erros:
%2</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="95"/>
        <location filename="../archive.cpp" line="178"/>
        <source>Unable to run the &quot;tar&quot; command: %1</source>
        <translation>Non foi posíbel executar a orde «tar»: %1</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="115"/>
        <source>Unable to create directory &quot;%1&quot;: %2</source>
        <translation>Non foi posíbel crear o directorio «%1»: %2</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="138"/>
        <source>&quot;%1&quot; does not appear to be a valid Openbox theme directory</source>
        <translation>Semella que «%1» non é un directorio de tema correcto para o Openbox</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="148"/>
        <source>Unable to move to directory &quot;%1&quot;: %2</source>
        <translation>Non é posíbel mover ao directorio «%1»: %2</translation>
    </message>
    <message>
        <location filename="../archive.cpp" line="185"/>
        <source>Unable to extract the file &quot;%1&quot;.
Please ensure that &quot;%2&quot; is writable and that the file is a valid Openbox theme archive.
The following errors were reported:
%3</source>
        <translation>Non foi posíbel extraer o ficheiro «%1».
Asegúrese de que pode escribir en «%2» e de que o ficheiro é un arquivo de tema correcto para o Openbox.
Informáronse os seguintes erros:
%3</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="53"/>
        <source>ObConf Error</source>
        <translation>Produciuse un erro no ObConf</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="73"/>
        <source>Syntax: obconf [options] [ARCHIVE.obt]

Options:
  --help                Display this help and exit
  --version             Display the version and exit
  --install ARCHIVE.obt Install the given theme archive and select it
  --archive THEME       Create a theme archive from the given theme directory
  --config-file FILE    Specify the path to the config file to use
</source>
        <translation>Syntaxe: obconf [opcións] [ARQUIVO.obt]

Opcións:
  --help                 Amosa esta axuda e sae
  --version              Amosa a versión e sae
  --install ARQUIVO.obt  Instala o arquivo indicado do tema e selecciónao
  --archive TEMA         Crea un arquivo do tema do directorio de tema indicado
  --config-file FICHEIRO Especifica a ruta ao ficheiro de configuración que usar
</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="97"/>
        <source>--install requires an argument
</source>
        <translation>--install require un argumento
</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="103"/>
        <source>--archive requires an argument
</source>
        <translation>--archive require un argumento
</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="109"/>
        <source>--config-file requires an argument
</source>
        <translation>--config-file require un argumento
</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="223"/>
        <location filename="../obconf-qt.cpp" line="238"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="224"/>
        <source>Failed to load an rc.xml. You have probably failed to install Openbox properly.</source>
        <translation>Non foi posíbel cargar un rc.xml. Probabelmente non conseguiu instalar o Openbox correctamente.</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="236"/>
        <source>Error while parsing the Openbox configuration file.  Your configuration file is not valid XML.

Message: %1</source>
        <translation>Produciuse un erro ao analizar o ficheiro de configuración do Openbox .  O ficheiro de configuración non é un XML correcto.

Mensaxe: %1</translation>
    </message>
    <message>
        <location filename="../obconf-qt.cpp" line="58"/>
        <source>Copyright (c) 2003-2008   Dana Jansens
Copyright (c) 2003        Tim Riley
Copyright (c) 2007        Javeed Shaikh
Copyright (c) 2013        Hong Jen Yee (PCMan)

This program comes with ABSOLUTELY NO WARRANTY.
This is free software, and you are welcome to redistribute it
under certain conditions. See the file COPYING for details.

</source>
        <translation>Copyright (c) 2003-2008   Dana Jansens
Copyright (c) 2003        Tim Riley
Copyright (c) 2007        Javeed Shaikh
Copyright (c) 2013        Hong Jen Yee (PCMan)

Este programa non ten ABSOLUTAMENTE NINGUNHA GARANTÍA.
Isto é software libre, convidámolo a redistribuílo baixo certas
condicións. Vexa o ficheiro COPYING para obter máis detalles.

</translation>
    </message>
</context>
</TS>
